////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2018 Saxonica Limited.
// This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
// If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.
// This Source Code Form is "Incompatible With Secondary Licenses", as defined by the Mozilla Public License, v. 2.0.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

package net.sf.saxon.trans.rules;

/**
 * A simple class for holding stateful details of a rule search operation
 * This is a dummy implementation for Saxon-HE which does not optimize searching a rule chain.
 * It is subclassed for Saxon-EE.
 */
public class RuleSearchState {

    public RuleSearchState() {}


}

